FunctionView

Struct FunctionView 

pub struct FunctionView<'a, 'c, 'd, 'e, F: FunctionRepr, Context: FunctionQuery<A::Address>, A: Arch + BaseDisplay<F, Context> + SSAValues, M: MemoryRepr<A> + MemoryRange<A>> {
    pub _function_type: PhantomData<F>,
    pub data: &'a M,
    pub ctx: Context,
    pub fn_graph: &'c ControlFlowGraph<A::Address>,
    pub ssa: Option<&'d SSA<A>>,
    pub colors: Option<&'e ColorSettings>,
    pub highlight_instrs: Vec<A::Address>,
    pub highlight_locs: Vec<(A::Address, A::Location, Direction)>,
}
This view in particular takes optionally-present data flow information, which ends up restricting the usefulness of this struct to architectures that have SSA information defined. a handy TODO: here is to either figure out how to have a default Location that specifies no locations, and a corresponding data flow reference that never returns locations, OR to figure out if there should be a different FunctionView for non-location-enabled architectures.

Anyway the question of highlighting operands is architecture-independent and only requires that operands are known, which is true by virtue of Arch being implemented

Fields

_function_type: PhantomData<F>data: &'a Mctx: Contextfn_graph: &'c ControlFlowGraph<A::Address>ssa: Option<&'d SSA<A>>colors: Option<&'e ColorSettings>highlight_instrs: Vec<A::Address>highlight_locs: Vec<(A::Address, A::Location, Direction)>