InstructionModifiers

Struct InstructionModifiers 

pub struct InstructionModifiers<A: Arch + ValueLocations>{
    pub calls: HashMap<A::Address, A::Address>,
    /* private fields */
}
The Vec<ModifierExpression> are conjunctions. This differs from ValueSet, which uses a sequence of values as disjunctions. This means there’s no way to express a sparseset of values as ModifierExpression, for the time being.

Fields

calls: HashMap<A::Address, A::Address>

Implementations

Source

impl<A: Arch + ValueLocations> InstructionModifiers<A>

pub fn new( fn_query: Rc<RefCell<HashMap<A::Address, FunctionImpl<A::Location>>>>, ) -> Self

pub fn modifiers_between( &self, from: A::Address, to: A::Address, ) -> Option<&HashMap<Option<A::Location>, Vec<ModifierExpression>>>

pub fn add_edge_modifier( &mut self, from: A::Address, to: A::Address, loc: Option<A::Location>, expr: ModifierExpression, )