pub struct FunctionView<'a, 'c, 'd, 'e, F: FunctionRepr, Context: FunctionQuery<A::Address>, A: Arch + BaseDisplay<F, Context> + SSAValues, M: MemoryRepr<A> + MemoryRange<A>> {
pub _function_type: PhantomData<F>,
pub data: &'a M,
pub ctx: Context,
pub fn_graph: &'c ControlFlowGraph<A::Address>,
pub ssa: Option<&'d SSA<A>>,
pub colors: Option<&'e ColorSettings>,
pub highlight_instrs: Vec<A::Address>,
pub highlight_locs: Vec<(A::Address, A::Location, Direction)>,
}Expand description
This view in particular takes optionally-present data flow information, which ends up
restricting the usefulness of this struct to architectures that have SSA information defined.
a handy TODO: here is to either figure out how to have a default Location that specifies no
locations, and a corresponding data flow reference that never returns locations, OR to figure
out if there should be a different FunctionView for non-location-enabled architectures.
Anyway the question of highlighting operands is architecture-independent and only requires that
operands are known, which is true by virtue of Arch being implemented
Fields
_function_type: PhantomData<F>data: &'a Mctx: Contextfn_graph: &'c ControlFlowGraph<A::Address>ssa: Option<&'d SSA<A>>colors: Option<&'e ColorSettings>highlight_instrs: Vec<A::Address>highlight_locs: Vec<(A::Address, A::Location, Direction)>Trait Implementations
Sourceimpl<'a, 'c, 'd, 'e, A, F: FunctionRepr, Context: FunctionQuery<A::Address> + SymbolQuery<A::Address>, M: MemoryRepr<A> + MemoryRange<A>> FunctionDisplay<A> for FunctionView<'a, 'c, 'd, 'e, F, Context, A, M>where
A: Arch + SSAValues + FunctionInstructionDisplay<A, Context> + DecodeFrom<M> + BaseDisplay<F, Context>,
impl<'a, 'c, 'd, 'e, A, F: FunctionRepr, Context: FunctionQuery<A::Address> + SymbolQuery<A::Address>, M: MemoryRepr<A> + MemoryRange<A>> FunctionDisplay<A> for FunctionView<'a, 'c, 'd, 'e, F, Context, A, M>where
A: Arch + SSAValues + FunctionInstructionDisplay<A, Context> + DecodeFrom<M> + BaseDisplay<F, Context>,
fn entrypoint(&self) -> A::Address
fn remove_highlight_instr(&mut self, addr: A::Address)
fn add_highlight_instr(&mut self, addr: A::Address)
fn add_highlight_loc(&mut self, loc: (A::Address, A::Location, Direction))
fn reset_highlight_instrs(&mut self)
fn reset_highlight_locs(&mut self)
fn view_between( &self, start: Option<A::Address>, end: Option<A::Address>, ) -> Vec<(A::Address, Vec<String>)>